import './App.css';
import React from 'react';
import { BrowserRouter, Routes, Route } from 'react-router-dom';

import Header from './container/Header';
import About from "./components/About"
import Games from './container/Games';
import Leaderboard from './container/Leaderboard';

import useUserReducer from './reducer/user';
import usePollingReducer from './reducer/polling';
import useLeaderboardReducer from './reducer/leaderboard';
import useGamesReducer from './reducer/games';

import useUserApi from './api/user';
import useLeaderboardApi from './api/leaderboard';
import useGamesApi from './api/games';

function App() {
  const userReducer = useUserReducer();
  const pollingReducer = usePollingReducer();
  const leaderboardReducer = useLeaderboardReducer();
  const gamesReducer = useGamesReducer();

  const user = useUserApi(userReducer).get();
  const leaderboard = useLeaderboardApi(leaderboardReducer).poll(pollingReducer);
  /*const gamesApi = */ useGamesApi(gamesReducer).list(pollingReducer);

  return (
    <BrowserRouter>
      <Header pollingReducer={pollingReducer} />
      <Routes>
        <Route path="/" element={<About />} />
        <Route path="/about" element={<About />} />
        <Route path="/games/*" element={<Games />} />
        <Route path="/leaderboard" element={<Leaderboard leaderboard={leaderboard} user={user} />} />
      </Routes>
    </BrowserRouter>
  )
}

export default App;
